package com.ruoyi.pay.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.domain.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import com.ruoyi.pay.domain.bo.PayButieEmplyeeBo;
import com.ruoyi.pay.domain.vo.PayButieEmplyeeVo;
import com.ruoyi.pay.domain.PayButieEmplyee;
import com.ruoyi.pay.mapper.PayButieEmplyeeMapper;
import com.ruoyi.pay.service.IPayButieEmplyeeService;

import java.util.List;
import java.util.Map;
import java.util.Collection;

/**
 * 补贴和员工联系Service业务层处理
 *
 * @author ruoyi
 * @date 2025-05-12
 */
@RequiredArgsConstructor
@Service
public class PayButieEmplyeeServiceImpl implements IPayButieEmplyeeService {

    private final PayButieEmplyeeMapper baseMapper;

    /**
     * 查询补贴和员工联系
     */
    @Override
    public PayButieEmplyeeVo queryById(Long id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询补贴和员工联系列表
     */
    @Override
    public TableDataInfo<PayButieEmplyeeVo> queryPageList(PayButieEmplyeeBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<PayButieEmplyee> lqw = buildQueryWrapper(bo);
        Page<PayButieEmplyeeVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询补贴和员工联系列表
     */
    @Override
    public List<PayButieEmplyeeVo> queryList(PayButieEmplyeeBo bo) {
        LambdaQueryWrapper<PayButieEmplyee> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<PayButieEmplyee> buildQueryWrapper(PayButieEmplyeeBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<PayButieEmplyee> lqw = Wrappers.lambdaQuery();
        lqw.eq(bo.getTenantId() != null, PayButieEmplyee::getTenantId, bo.getTenantId());
        lqw.eq(bo.getButieId() != null, PayButieEmplyee::getButieId, bo.getButieId());
        lqw.eq(bo.getEmployeeId() != null, PayButieEmplyee::getEmployeeId, bo.getEmployeeId());
        lqw.eq(bo.getMoney() != null, PayButieEmplyee::getMoney, bo.getMoney());
        lqw.eq(StringUtils.isNotBlank(bo.getDate()), PayButieEmplyee::getDate, bo.getDate());
        return lqw;
    }

    /**
     * 新增补贴和员工联系
     */
    @Override
    public Boolean insertByBo(PayButieEmplyeeBo bo) {
        PayButieEmplyee add = BeanUtil.toBean(bo, PayButieEmplyee.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    /**
     * 修改补贴和员工联系
     */
    @Override
    public Boolean updateByBo(PayButieEmplyeeBo bo) {
        PayButieEmplyee update = BeanUtil.toBean(bo, PayButieEmplyee.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(PayButieEmplyee entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除补贴和员工联系
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }
}
