package com.ruoyi.pay.controller;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.pay.domain.vo.PayRequireAttendanceReportVo;
import com.ruoyi.pay.domain.bo.PayRequireAttendanceReportBo;
import com.ruoyi.pay.service.IPayRequireAttendanceReportService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 应出勤报
 *
 * @author ruoyi
 * @date 2025-05-12
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/pay/requireAttendanceReport")
public class PayRequireAttendanceReportController extends BaseController {

    private final IPayRequireAttendanceReportService iPayRequireAttendanceReportService;

    /**
     * 查询应出勤报列表
     */
    @SaCheckPermission("pay:requireAttendanceReport:list")
    @GetMapping("/list")
    public TableDataInfo<PayRequireAttendanceReportVo> list(PayRequireAttendanceReportBo bo, PageQuery pageQuery) {
        return iPayRequireAttendanceReportService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出应出勤报列表
     */
    @SaCheckPermission("pay:requireAttendanceReport:export")
    @Log(title = "应出勤报", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(PayRequireAttendanceReportBo bo, HttpServletResponse response) {
        List<PayRequireAttendanceReportVo> list = iPayRequireAttendanceReportService.queryList(bo);
        ExcelUtil.exportExcel(list, "应出勤报", PayRequireAttendanceReportVo.class, response);
    }

    /**
     * 获取应出勤报详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("pay:requireAttendanceReport:query")
    @GetMapping("/{id}")
    public R<PayRequireAttendanceReportVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable Long id) {
        return R.ok(iPayRequireAttendanceReportService.queryById(id));
    }

    /**
     * 新增应出勤报
     */
    @SaCheckPermission("pay:requireAttendanceReport:add")
    @Log(title = "应出勤报", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody PayRequireAttendanceReportBo bo) {
        return toAjax(iPayRequireAttendanceReportService.insertByBo(bo));
    }

    /**
     * 修改应出勤报
     */
    @SaCheckPermission("pay:requireAttendanceReport:edit")
    @Log(title = "应出勤报", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody PayRequireAttendanceReportBo bo) {
        return toAjax(iPayRequireAttendanceReportService.updateByBo(bo));
    }

    /**
     * 删除应出勤报
     *
     * @param ids 主键串
     */
    @SaCheckPermission("pay:requireAttendanceReport:remove")
    @Log(title = "应出勤报", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable Long[] ids) {
        return toAjax(iPayRequireAttendanceReportService.deleteWithValidByIds(Arrays.asList(ids), true));
    }
}
